# -*- coding: utf-8 -*-
from .validators import is_safe_username

__all__ = ["is_safe_username"]
